@@ -8,7 +8,7 @@ from muffin.plugins import BasePlugin
 from apiclient import APIClient
 
 
-__version__ = "0.1.2"
+__version__ = "1.1.2"
 __project__ = "muffin-apiclient"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -56,6 +56,9 @@ class Plugin(BasePlugin):
         )
         self.api = self.client.api
 
+    def __getattr__(self, name):
+        return getattr(self.client, name)
+
     async def startup(self):
         """Startup self client."""
         await self.client.startup()
